@@ -13,15 +13,17 @@
   
   packageStartupMessage(
     "Overriding + and - methods for POSIXt, Date and difftime")
-
-  utils::assignInNamespace("+.Date",     add_dates, "base")
-  utils::assignInNamespace("+.POSIXt",   add_dates, "base")
-  utils::assignInNamespace("+.difftime", add_dates, "base")
-  utils::assignInNamespace("-.Date",     subtract_dates, "base")
-  utils::assignInNamespace("-.POSIXt",   subtract_dates, "base")
-  utils::assignInNamespace("-.difftime", subtract_dates, "base")
-  utils::assignInNamespace("/.difftime", divide_dates, "base")
-
+    
+  suppressWarnings({
+    utils::assignInNamespace("+.Date",     add_dates, "base")
+    utils::assignInNamespace("+.POSIXt",   add_dates, "base")
+    utils::assignInNamespace("+.difftime", add_dates, "base")
+    utils::assignInNamespace("-.Date",     subtract_dates, "base")
+    utils::assignInNamespace("-.POSIXt",   subtract_dates, "base")
+    utils::assignInNamespace("-.difftime", subtract_dates, "base")
+    utils::assignInNamespace("/.difftime", divide_dates, "base")
+  })
+  
   # Needed so that environment matches environment of add_dates above
   utils::assignInNamespace("+.period",   add_dates, "lubridate")
   utils::assignInNamespace("+.interval", add_dates, "lubridate")
