@@ -632,72 +632,6 @@ test_that("multiplication still works for numbers",{
 })
 
 
-# division for everything
-
-test_that("division throws error for instants",{
-  x <- as.POSIXct("2010-03-15 00:00:00", tz = "UTC")
-  
-  expect_that(3 / x, throws_error())
-  expect_that(x / 3, throws_error())
-  
-})
-
-test_that("division throws error for intervals",{
-  time1 <- as.POSIXct("2008-08-03 00:00:00", tz = "UTC") 
-  time2 <- as.POSIXct("2009-08-03 00:00:00", tz = "UTC")
-  int <- new_interval(time2, time1)
-  diff <- difftime(time2, time1)
-  int2 <- new_interval(time1 + diff/2, time1)
-    
-  expect_that(int / 2, equals(int2))
-})
-
-test_that("division works as expected for periods",{
-  
-  expect_that(3/months(1), throws_error())
-  expect_that(months(1)/3, throws_error(
-    "periods must have integer values"))
-  expect_that(months(9)/3, equals(months(3)))
-  expect_that(months(9)/3, is_a("period"))
-  
-})
-
-test_that("dividing vectors works for periods",{
-  
-  expect_that(c(2,3)/months(1), throws_error())
-  expect_that(months(1)/c(2,3), throws_error(
-    "periods must have integer values"))
-  expect_that(months(9)/c(3,1), equals(months(c(3,9))))
-  expect_that(months(9)/c(3,1), is_a("period"))
-  
-})
-
-test_that("division works as expected for durations",{
-    
-  expect_that(3/ehours(1), throws_error())
-  expect_that(ehours(9)/3, equals(ehours(3)))
-  expect_that(ehours(9)/3, is_a("duration"))
-  
-})
-
-test_that("dividing vectors works for durations",{
-  
-  expect_that(c(2,3)/ehours(1), throws_error())
-  expect_that(ehours(9)/c(3,1), equals(ehours(c(3,9))))
-  expect_that(ehours(9)/c(3,1), is_a("duration"))
-  
-})
-
-test_that("division still works for numbers",{
-  expect_that(6/2, equals(3))
-  expect_that(c(4,6)/2, equals(c(2,3)))
-  expect_that(3/2, is_a("numeric"))
-  
-})
-
-
-
-
 test_that("make_difftime makes a correct difftime object",{
   x <- as.POSIXct("2008-01-01 12:00:00", tz = "UTC")
   y <- difftime(x + 3600, x)
